=============
Release Notes
=============

v1.0
----

**Breaking Changes**:
  * Close #9: Add URL slugs for articles and categories. This will
    break any links from external sources.
  * Close #18: Remove search functionality.

**Features:**
  * Close #27: The article list is now paginated.
  * Close #28: The string representation of a category now includes
    information about its parent category.

**Documentation:**
  * Close #8: Create initial documentation.
